@@ -22,30 +22,32 @@ ci.auc <- function(...) {
 }
 
 ci.auc.formula <- function(formula, data, ...) {
-	# Get the data. Use standard code from survival::coxph as suggested by Terry Therneau
-	Call <- match.call()
-	indx <- match(c("formula", "data", "weights", "subset", "na.action"), names(Call), nomatch=0)
-	if (indx[1] == 0) {
-		stop("A formula argument is required")
+	data.missing <- missing(data)
+	roc.data <- roc_utils_extract_formula(formula, data, ..., 
+										  data.missing = data.missing,
+										  call = match.call())
+	if (length(roc.data$predictor.name) > 1) {
+		stop("Only one predictor supported in 'ci.auc'.")
 	}
-	# Keep the standard arguments and run them in model.frame
-	temp <- Call[c(1,indx)]  
-	temp[[1]] <- as.name('model.frame')
-	m <- eval(temp, parent.frame())
-	
-	if (!is.null(model.weights(m))) stop("weights are not supported")
-	
-	response <- model.response(m)
-	predictor <- m[[attr(terms(formula), "term.labels")]]
+	response <- roc.data$response
+	predictor <- roc.data$predictors[, 1]
 	ci.auc.roc(roc.default(response, predictor, ci=FALSE, ...), ...)
 }
 
 ci.auc.default <- function(response, predictor, ...) {
-  ci.auc.roc(roc.default(response, predictor, ci=FALSE, ...), ...)
+	roc <- roc.default(response, predictor, ci = FALSE, ...)
+	if (methods::is(roc, "smooth.roc")) {
+		return(ci.auc(smooth.roc = roc, ...))
+	}
+	else {
+		return(ci.auc(roc = roc, ...))
+	}
 }
 
 ci.auc.auc <- function(auc, ...) {
-  ci.auc(attr(auc, "roc"), ...)
+	roc <- attr(auc, "roc")
+	roc$auc <- auc
+	ci.auc(roc, reuse.auc = TRUE, ...)
 }
 
 ci.auc.smooth.roc <- function(smooth.roc,
@@ -60,7 +62,7 @@ ci.auc.smooth.roc <- function(smooth.roc,
   if (conf.level > 1 | conf.level < 0)
     stop("conf.level must be within the interval [0,1].")
   
-  if (roc.utils.is.perfect.curve(smooth.roc)) {
+  if (roc_utils_is_perfect_curve(smooth.roc)) {
   	warning("ci.auc() of a ROC curve with AUC == 1 is always 1-1 and can be misleading.")
   }
 
@@ -94,8 +96,8 @@ ci.auc.smooth.roc <- function(smooth.roc,
   auc.args$allow.invalid.partial.auc.correct <- TRUE
   auc.call <- as.call(c(utils::getS3method("auc", "smooth.roc"), auc.args))
 
-  if(class(progress) != "list")
-    progress <- roc.utils.get.progress.bar(progress, title="AUC confidence interval", label="Bootstrap in progress...", ...)
+  if(inherits(progress, "list"))
+    progress <- roc_utils_get_progress_bar(progress, title="AUC confidence interval", label="Bootstrap in progress...", ...)
 
   if (boot.stratified) {
     aucs <- unlist(llply(1:boot.n, stratified.ci.smooth.auc, roc=roc, smooth.roc.call=smooth.roc.call, auc.call=auc.call, .progress=progress, .parallel=parallel))
@@ -137,7 +139,7 @@ ci.auc.roc <- function(roc,
   if (conf.level > 1 | conf.level < 0)
     stop("conf.level must be within the interval [0,1].")
   
-  if (roc.utils.is.perfect.curve(roc)) {
+  if (roc_utils_is_perfect_curve(roc)) {
   	warning("ci.auc() of a ROC curve with AUC == 1 is always 1-1 and can be misleading.")
   }
 
@@ -149,7 +151,7 @@ ci.auc.roc <- function(roc,
   percent <- roc$percent
   oldauc <- roc$auc
   if (percent) {
-  	roc <- roc.utils.unpercent(roc)
+  	roc <- roc_utils_unpercent(roc)
   }
 
   # Check the method
@@ -179,9 +181,9 @@ ci.auc.roc <- function(roc,
   }
 
   if (method == "delong")
-    ci <- ci.auc.delong(roc, conf.level)
+    ci <- ci_auc_delong(roc, conf.level)
   else
-    ci <- ci.auc.bootstrap(roc, conf.level, boot.n, boot.stratified, progress, parallel, ...)
+    ci <- ci_auc_bootstrap(roc, conf.level, boot.n, boot.stratified, progress, parallel, ...)
 
   if (percent) {
     ci <- ci * 100
